<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/ecrire_?lang_cible=ast
// ** ne pas modifier le fichier **

return [

	// A
	'activer_plugin' => 'Activar el plugin',
	'affichage' => 'Compaxinación',
	'aide_non_disponible' => 'Esta parte de l’aida en llínia tovía nun tá iguada n’esta llingua.',
	'auteur' => 'Autor:',
	'avis_acces_interdit' => 'Accesu torgau.',
	'avis_article_modifie' => 'Atención, @nom_auteur_modif@ trabayó n’esti artículo hai @date_diff@ minutos.',
	'avis_aucun_resultat' => 'Dengún resultáu',
	'avis_chemin_invalide_1' => 'El camín escoyíu',
	'avis_chemin_invalide_2' => 'nun paez afayaízu. Torna a la páxina anterior y revisa la información qu’escribiste.',
	'avis_connexion_echec_1' => 'Falló l’enxertu al servidor SQL.',
	'avis_connexion_echec_2' => 'Torna a la páxina cabera y revisa los datos que pusiste.',
	'avis_connexion_echec_3' => '<b>Nota:</b> En munchos sirvidores, fai falta <b>pidir</b> la activación del accesu a la base de datos enantes de poder usala. Si nun puedes conectate, mira si ficiste esi trámite.',
	'avis_connexion_ldap_echec_1' => 'Hubo un fallu na conexón al sirvidor LDAP.',
	'avis_connexion_ldap_echec_2' => 'Torna a la páxina anterior, y revisa la información qu’escribisti n’ella.',
	'avis_connexion_ldap_echec_3' => 'D’otru mou, nun uses el sofitu de LDAP pa importar usuarios.', # MODIF
	'avis_deplacement_rubrique' => '¡Atención! Esta estaya contién @contient_breves@ breve@scb@: si la mueves, ties que marcar esti cuadru de confirmación.',
	'avis_erreur_connexion_mysql' => 'Fallu de conexón SQL',
	'avis_espace_interdit' => '<b>Espaciu torgáu</b> <div>SPIP ya ta instalao.</div>',
	'avis_lecture_noms_bases_1' => 'El programa d’instalación nun fue a lleer los nomes de les bases de datos instaláes.',
	'avis_lecture_noms_bases_2' => 'Puede ser que denguna base nun te disponible, o que la función que permite llistar les bases te desactivada
 por cuenta de razones de seguridá (lo que ye’l casu n’abondos agospiamientos web).',
	'avis_lecture_noms_bases_3' => 'Nel segundu casu, ye probable qu’esista una base que col mesmu nome qu’el to login:',
	'avis_non_acces_page' => 'Nun tienes accesu a esta páxina.',
	'avis_operation_echec' => 'Falló la operación.',
	'avis_operation_impossible' => 'Operación imposible',
	'avis_suppression_base' => 'ATENCIÓN, el desaniciu de los datos nun ye reversible',

	// B
	'bouton_acces_ldap' => 'Añader l’accesu a LDAP',
	'bouton_ajouter' => 'Amestar',
	'bouton_annuler' => 'Anular',
	'bouton_demande_publication' => 'Pedir l’espublizamientu d’esti artículu',
	'bouton_desactive_tout' => 'Desactivalo too',
	'bouton_desinstaller' => 'Desasitiar',
	'bouton_effacer_tout' => 'Desaniciar TOO',
	'bouton_envoyer_message' => 'Mensaxe definitivu: unviar',
	'bouton_fermer' => 'Zarrar',
	'bouton_mettre_a_jour' => 'Actualizar',
	'bouton_modifier' => 'Camudar',
	'bouton_radio_afficher' => 'Amosar',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Apaecer na llista de redactores coneutaos', # MODIF
	'bouton_radio_envoi_annonces_adresse' => 'Unviar los anuncios a la direición:',
	'bouton_radio_envoi_liste_nouveautes' => 'Unviar la llista de novedáes',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Nun apaecer na llista de redactores', # MODIF
	'bouton_radio_non_envoi_annonces_editoriales' => 'Nun mandar anuncios editoriales',
	'bouton_redirection' => 'REDIREICIÓN',
	'bouton_relancer_installation' => 'Rellanzar l’instalación',
	'bouton_suivant' => 'Siguiente',
	'bouton_tenter_recuperation' => 'Tentar una reparación',
	'bouton_test_proxy' => 'Comprobar el proxy',
	'bouton_vider_cache' => 'Vaciar la caché',

	// C
	'cache_modifiable_webmestre' => 'Esti parámetru puede modificase pol webmaster del sitiu.', # MODIF
	'calendrier_synchro' => 'Si uses un programa d’axenda compatible <b>iCal</b>, puedes sincronizalu cola información d’esti sitiu.',
	'config_activer_champs' => 'Activar los campos siguientes',
	'config_choix_base_sup' => 'indicar una base datos nesti sirvidor',
	'config_erreur_base_sup' => 'SPIP nun tien accesu a la llista de les bases disponibles',
	'config_info_base_sup' => 'Si tienes otres bases de datos pa restolar al traviés de SPIP, col so sirvidor SQL o con otru, el formulariu d’embaxo va permitite declarales. Si dexes ciertos campos vacíos, utilizaránse les identificaciones de conexón a la base principal.',
	'config_info_base_sup_disponibles' => 'Bases suplementaries que ya son restolables:',
	'config_info_enregistree' => 'Guardose la nueva configuración',
	'config_info_logos' => 'Cada elementu del sitiu puede tener un logo, lo mesmo qu’un «logo de pasu’l mur»',
	'config_info_logos_utiliser' => 'Usar los logos',
	'config_info_logos_utiliser_non' => 'Nun usar los logos',
	'config_info_logos_utiliser_survol' => 'Usar los logos de pasu’l mur',
	'config_info_logos_utiliser_survol_non' => 'Nun usar los logos de pasu’l mur',
	'config_info_redirection' => 'En activando esta opción, vas poder crear artículos virtuales, simples referencies d’artículos espublizáos n’otros sitios o fechos ensin SPIP.',
	'config_redirection' => 'Artículos virtuales',
	'config_titre_base_sup' => 'Declaración d’una base suplementaria',
	'config_titre_base_sup_choix' => 'Escueye una base suplementaria',
	'connexion_ldap' => 'Conexón:',

	// D
	'date_mot_heures' => 'hores',

	// E
	'email' => 'corréu electrónicu',
	'email_2' => 'correu elletrónicu:',
	'en_savoir_plus' => 'Pa saber más',
	'entree_adresse_annuaire' => 'Señes de l’anuariu',
	'entree_adresse_email' => 'Les tos señes d’email',
	'entree_base_donnee_1' => 'Señes de la base de datos',
	'entree_base_donnee_2' => '(Bien de veces estes señes correspuendense coles del sitiu mesmu, dacuando son el nome «localhost», o sinon dexense vacíes dafechu.)',
	'entree_biographie' => 'Biografía curtia en delles pallabres.',
	'entree_chemin_acces' => '<b>Enxertar</b> la ruta d’accesu:',
	'entree_cle_pgp' => 'La to clave PGP',
	'entree_contenu_rubrique' => '(Conteníu de la estaya en delles pallabres.)',
	'entree_identifiants_connexion' => 'Los identificadores pa la to conexón...',
	'entree_informations_connexion_ldap' => 'Nesti formulariu has d’enxertar la información pa coneutate al sirvidor de señes LDAP.
 Esta información tien que apurrítela l’alministrador del sistema,
 o de la rede.', # MODIF
	'entree_infos_perso' => '¿Quién yes?',
	'entree_interieur_rubrique' => 'Dientro de l’estaya:',
	'entree_liens_sites' => '<b>Enllaz d’hipertestu</b> (referencia, sitiu a visitar...)',
	'entree_login' => 'El to login',
	'entree_login_connexion_1' => 'El nome de conexón',
	'entree_login_connexion_2' => '(Correspuende seique al to nome d’accesu al FTP; seique en blancu)',
	'entree_mot_passe' => 'La to contraseña',
	'entree_mot_passe_1' => 'La contraseña pa la conexón',
	'entree_mot_passe_2' => '(Correspuende seique a la to contraseña pal FTP; seique en blancu)',
	'entree_nom_fichier' => 'Has d’amestar el nome de l’archivu @texte_compresse@:',
	'entree_nom_pseudo' => 'El to nome o nomatu',
	'entree_nom_pseudo_1' => '(El to nome o nomatu)',
	'entree_nom_site' => 'Nome del to sitiu web',
	'entree_nouveau_passe' => 'Contraseña nueva',
	'entree_passe_ldap' => 'Contraseña',
	'entree_port_annuaire' => 'Númberu de puertu del sirvidor de señes',
	'entree_signature' => 'Robla',
	'entree_titre_obligatoire' => '<b>Títulu</b> [Obligatoriu]<br />',
	'entree_url' => 'Les señes (URL) del to sitiu web',
	'erreur_plugin_desinstalation_echouee' => 'Falló la desinstalación del complementu. Sicasí, puedes desactivalu.', # MODIF
	'erreur_plugin_fichier_absent' => 'Falta l’archivu',
	'erreur_plugin_fichier_def_absent' => 'Falta l’archivu de definición',
	'erreur_plugin_nom_fonction_interdit' => 'Nome de función encaboxada',
	'erreur_plugin_nom_manquant' => 'Falta’l nome del plugin',
	'erreur_plugin_prefix_manquant' => 'Espaciu de nomes del plugin nun definíu',
	'erreur_plugin_tag_plugin_absent' => 'Falta el &lt;plugin&gt; nel archivu de definición',
	'erreur_plugin_version_manquant' => 'Falta la versión del plugin',

	// H
	'htaccess_a_simuler' => 'Avisu: la configuración del to sirvidor HTTP nun tien en cuenta los ficheros @htaccess@. Pa poder asegurar una bona seguridá, fai falta que camudes esa configuración nesti puntu, o bien que les constantes @constantes@ (definibles nel ficheru mes_options.php) tengan como valor direutorios nel esterior de @document_root@.', # MODIF
	'htaccess_inoperant' => 'htaccess non operativu',

	// I
	'ical_info1' => 'N’esta páxina ufrense delles maneres de tar en contautu cola actividá d’esti sitiu.',
	'ical_info2' => 'Pa más información tocante a toes estes técniques, pues consultar <a href="@spipnet@">la documentación de SPIP</a>.',
	'ical_info_calendrier' => 'Tienes dos axendes a la to disposición. La primera ye el plan del sitiu que anuncia tolos artículos espublizaos. La segunda contién los anuncios editoriales y también los tos caberos mensaxes privaos: esta ye una axenda privada gracies a una clave personal, que pues modificar en tou momentu anovando la to contraseña.',
	'ical_methode_http' => 'Descarga',
	'ical_methode_webcal' => 'Sincronización (webcal://)', # MODIF
	'ical_texte_prive' => 'Esta axenda, de usu esclusivamente personal, te informa de l’actividá editorial privada d’esti sitiu (xeres y conceyos personales, artículos y breves propuestos...).',
	'ical_texte_public' => 'Esta axenda te permite siguir l’actividá pública d’esti sitiu (artículos y breves espublizáos).',
	'ical_texte_rss' => 'Puedes sindicar les novedáes d’esti sitiu en cualisquier llector d’archivos en formatu XML/RSS (Rich Site Summary). Esti ye también el formatu que permite a SPIP lleer les novedáes espublizáes n’otros sitios que utilicen un formatu d’intercambéu compatible (sitios sindicaos).',
	'ical_titre_js' => 'Javascript',
	'ical_titre_mailing' => 'Llista de corréu',
	'ical_titre_rss' => 'Archivos de sindicación',
	'icone_accueil' => 'Entamu',
	'icone_activer_cookie' => 'Activar la cookie de correspondencia',
	'icone_activite' => 'Actividá',
	'icone_admin_plugin' => 'Xestión de los plugins',
	'icone_administration' => 'Mantenimientu',
	'icone_afficher_auteurs' => 'Amosar los autores',
	'icone_afficher_visiteurs' => 'Amosar les visites',
	'icone_arret_discussion' => 'Nun participar ya nesta discusión',
	'icone_calendrier' => 'Calendariu',
	'icone_configuration' => 'Configuración',
	'icone_creer_auteur' => 'Crear un nuevu autor y asocialu con esti artículu',
	'icone_creer_mot_cle' => 'Crear una nueva pallabra-clave y amestala con esti artículu',
	'icone_creer_rubrique_2' => 'Facer una estaya nueva',
	'icone_edition' => 'Edición',
	'icone_ma_langue' => 'La mio llingua',
	'icone_mes_infos' => 'La mio información',
	'icone_mes_preferences' => 'Les mios preferencies',
	'icone_modifier_article' => 'Iguar esti artículu',
	'icone_modifier_rubrique' => 'Iguar esta estaya',
	'icone_publication' => 'Publicación',
	'icone_relancer_signataire' => 'Rellanzar el roblador',
	'icone_retour' => 'Tornar',
	'icone_retour_article' => 'Tornar a l’artículu',
	'icone_squelette' => 'Cadarmes',
	'icone_suivi_publication' => 'Siguimientu de la publicación',
	'icone_supprimer_cookie' => 'Desaniciar la cookie de correspondencia',
	'icone_supprimer_rubrique' => 'Desaniciar esta estaya',
	'icone_supprimer_signature' => 'Desaniciar esta robla',
	'icone_valider_signature' => 'Validar esta robla',
	'image_administrer_rubrique' => 'Puedes alministrar esta estaya',
	'impossible_modifier_login_auteur' => 'Impossible de modifier le login.', # MODIF
	'impossible_modifier_pass_auteur' => 'Impossible de modifier le mot de passe.', # MODIF
	'info_1_article' => '1 artículu',
	'info_1_auteur' => '1 autor',
	'info_1_message' => '1 mensaxe',
	'info_1_mot_cle' => '1 pallabra-clave',
	'info_1_rubrique' => '1 seición',
	'info_1_visiteur' => '1 visitante',
	'info_activer_cookie' => 'Puedes activar una <b>cookie de correspondencia</b>, que va
 permitite que pases fácilmente del sitiu públicu al sitiu privau.',
	'info_admin_etre_webmestre' => 'Conseñame permisos de webmaster',
	'info_admin_je_suis_webmestre' => 'Yá soi <b>webmaster</b>',
	'info_admin_statuer_webmestre' => 'Da-y a esti alministrador permisos de webmaster', # MODIF
	'info_admin_webmestre' => 'Esti alministrador ye <b>webmaster</b>', # MODIF
	'info_administrateur' => 'Xestión', # MODIF
	'info_administrateur_1' => 'Xestión', # MODIF
	'info_administrateur_2' => 'de la web (<i>úsalo con cuidáu</i>)',
	'info_administrateur_site_01' => 'Si tas nel equipu de xestión,', # MODIF
	'info_administrateur_site_02' => 'pica n’esti enllaz',
	'info_administrateurs' => 'Alministradores', # MODIF
	'info_administrer_rubrique' => 'Puedes alministrar esta estaya',
	'info_adresse' => 'a les señes:',
	'info_adresse_url' => 'Direición (URL) del sitiu públicu',
	'info_aide_en_ligne' => 'Aida en llinia de SPIP',
	'info_ajout_image' => 'Cuando amestes imáxenes como documentos axuntaos a un artículu,
  SPIP puede crear por tí, automáticamente, viñetes (miniatures) de les
  imáxenes inxertaes. Esto permite por exemplu crear
  automáticamente una galería o un álbum.',
	'info_ajouter_rubrique' => 'Amestar otra estaya pa alministrar:',
	'info_annonce_nouveautes' => 'Anunciu de les novedáes',
	'info_article' => 'artículu',
	'info_article_2' => 'artículos',
	'info_article_a_paraitre' => 'Los artículos que apaecerán en feches futures',
	'info_articles_02' => 'artículos',
	'info_articles_2' => 'Artículos',
	'info_articles_auteur' => 'Los artículos d’esti autor',
	'info_articles_trouves' => 'Artículos alcontraos',
	'info_attente_validation' => 'Los tos artículos esperando validación',
	'info_aucun_article' => 'Dengún artículu',
	'info_aucun_auteur' => 'Dengún autor',
	'info_aucun_message' => 'Dengún mensaxe',
	'info_aucun_rubrique' => 'Denguna seición', # MODIF
	'info_aujourdhui' => 'güei:',
	'info_auteur_gere_toutes_rubriques_2' => 'Je gère <b>toutes les rubriques</b>', # MODIF
	'info_auteurs' => 'Los autores',
	'info_auteurs_par_tri' => 'Autores@partri@',
	'info_auteurs_trouves' => 'Autores alcontráos',
	'info_authentification_externe' => 'Autentificación esterna',
	'info_avertissement' => 'Avisu',
	'info_barre_outils' => 'cola so barra de ferramientes?',
	'info_base_installee' => 'L’armazón de la base de datos ta instalada.',
	'info_chapeau' => 'Cabecera',
	'info_chapeau_2' => 'Cabecera:',
	'info_chemin_acces_1' => 'Opciones: <b>Camín d’accesu na guía</b>',
	'info_chemin_acces_2' => 'Agora debes configurar el camín d’accesu a la información de la guía. Esta información ye indispensable pa lleer los perfiles d’usuariu guardáos na guía.', # MODIF
	'info_chemin_acces_annuaire' => 'Opciones: <b>Camín d’accesu na guía</b>',
	'info_choix_base' => 'Tercera etapa:',
	'info_classement_1' => '<sup>u</sup> en @liste@',
	'info_classement_2' => '<sup>u</sup> en @liste@',
	'info_code_acces' => '¡Nun escaezas los tos códigos d’accesu!',
	'info_config_suivi' => 'Si estes señes corresponden a una llista de corréu, pues indicar embaxo les señes nes que pueden apuntase los participantes nel sitiu. Estes señes puen ser una URL (por exemplu la páxina d’inscripción a la llista na Rede), o unes señes d’email con un asuntu específicu (por exemplu: <tt>@adresse_suivi@?subject=subscribe</tt>):',
	'info_config_suivi_explication' => 'Puedes soscribite a la llista de corréu d’esti sitiu. D’esti mou recibirás per corréu electrónicu los anuncios d’artículos y de breves propuestos pa espublizar.',
	'info_confirmer_passe' => 'Confirmar esta nueva contraseña:',
	'info_conflit_edition_avis_non_sauvegarde' => 'Atención, los campos siguientes camudáronse n’otra parte. Poro, les modificaciones dientro d’esos campos nun se grabaron.',
	'info_conflit_edition_differences' => 'Diferencies:',
	'info_conflit_edition_version_enregistree' => 'La versión grabada:',
	'info_conflit_edition_votre_version' => 'La to versión:',
	'info_connexion_base' => 'Preba de conexón a la base',
	'info_connexion_base_donnee' => 'Conexón cola to base de datos',
	'info_connexion_ldap_ok' => 'La conexón LDAP funcionó.</b><p> Puedes pasar a la etapa siguiente.</p>', # MODIF
	'info_connexion_mysql' => 'La to conexón SQL',
	'info_connexion_ok' => 'La conexón funcionó.',
	'info_contact' => 'Contautu',
	'info_contenu_articles' => 'Conteníu de los artículos',
	'info_contributions' => 'Collaboraciones',
	'info_creation_paragraphe' => '(Pa crear párrafos, dexa llínies vacíes ente ellos.)', # MODIF
	'info_creation_rubrique' => 'Enantes que puedas escribir artículos<br />debes crear polo menos una estaya.<br />',
	'info_creation_tables' => 'Creación de les tables de la base',
	'info_creer_base' => '<b>Crear</b> una nueva base datos:',
	'info_dans_rubrique' => 'Na estaya:',
	'info_date_publication_anterieure' => 'Fecha de redaición anterior:',
	'info_date_referencement' => 'FECHA DE REFERENCIACIÓN D’ESTI SITIU:',
	'info_derniere_etape' => '¡Ya finamos!',
	'info_descriptif' => 'Descripción:',
	'info_desinstaller_plugin' => 'desanicia los datos y desactiva el plugin',
	'info_discussion_cours' => 'Discutinios en cursu',
	'info_ecrire_article' => 'Enantes que puedas escribir artículos, tienes que crear polo menos una estaya.',
	'info_email_envoi' => 'Señes d’email d’unvíu (opcional)',
	'info_email_envoi_txt' => 'Indica equí les señes a utilizar pa unviar los emails (por omisión, usense les señes del destinatariu como señes d’unvíu):',
	'info_email_webmestre' => 'Señes d’email del webmaster (opcional)', # MODIF
	'info_envoi_email_automatique' => 'Unvíu d’e-mails automáticu',
	'info_envoyer_maintenant' => 'Unviar agora',
	'info_etape_suivante' => 'Pasar a la etapa siguiente',
	'info_etape_suivante_1' => 'Puedes pasar a la etapa siguiente.',
	'info_etape_suivante_2' => 'Puedes pasar a la etapa siguiente.',
	'info_exceptions_proxy' => 'Esceiciones pal proxy',
	'info_exportation_base' => 'esportación de la base a @archive@',
	'info_facilite_suivi_activite' => 'Col envís de facilitar el siguimientu de l’actividá
  editorial del sitiu, SPIP pue comunicar por e-mail, por exemplu
  a una llista de corréu de redactores, l’anunciu de les propuestes de
  publicación y les validaciones d’artículos.', # MODIF
	'info_fichiers_authent' => 'Archivos d’autentificación «.htpasswd»',
	'info_forums_abo_invites' => 'Esti sitiu tien foros pa abonaos; poro a los visiteurs se-yos encamienta que se rexistren nel sitiu públicu.', # MODIF
	'info_gauche_admin_tech' => '<b>Esta páxina namái ye accesible pa los responsables del sitiu.</b><p> Equí ta l’accesu a les diferentes
funciones de mantenimientu téunicu. Delles llancen un procesu d’identificación específicu, pal que
fai falta tener accesu per FTP al sirvidor del sitiu Web.</p>',
	'info_gauche_auteurs' => 'Equí s’alcuentren tolos autores del sitiu.
 El so estatutu vien indicáu pola color de l’iconu (alministrador = verde; redactor = mariellu).', # MODIF
	'info_gauche_auteurs_exterieurs' => 'Los autores esternos, ensin accesu al sitiu, vienen indicaos con un iconu azul;
  los autores esborráos con un calderu de basoria.', # MODIF
	'info_gauche_messagerie' => 'La mensaxería permite mandase mensaxes ente redactores, conservar recordatorioss (pa usu personal) o amosar anuncies na páxina principal de l’espaciu priváu (si yes alministrador).', # MODIF
	'info_gauche_statistiques_referers' => 'Esta páxina presenta la llista de los <i>referers</i>, que son sitios que contienen enllaces que apunten pa esti mesmu sitiu, namái d’ayeri y de güei; esta llista ponse a cero cada 24 hores.',
	'info_gauche_visiteurs_enregistres' => 'Equí alcontrarás los visitantes rexistraes
 nel espaciu públicu del sitiu (foros pa abonaos).',
	'info_generation_miniatures_images' => 'Xeneración d’imaxes amenorgáes',
	'info_hebergeur_desactiver_envoi_email' => 'Dellos agospiamientos encaboxen l’unvíu automáticu de
  correos dende los sos sirvidores. Nesti casu, les siguientes
  carauterístiques de SPIP nun funcionarán.',
	'info_hier' => 'ayeri:',
	'info_identification_publique' => 'La to identidá pública...',
	'info_image_process' => 'Has d’escoyer el meyor métodu de fabricación de les viñetes calcando enriba de la imaxe correspondiente.',
	'info_image_process2' => '<b>N.B.</b> <i>Si nun apaez imaxe dala, el sirvidor que agospia el to sitiu nun ta configuráu pa mandase d’estes ferramientes. Si quiés utilizar estes funciones, contauta col responsable téunicu y pide-y les estensiones «GD» o «Imagick».</i>', # MODIF
	'info_images_auto' => 'Imaxes calculáes automáticamente',
	'info_informations_personnelles' => 'Información personal',
	'info_inscription_automatique' => 'Inscripción automática de redactores nuevos', # MODIF
	'info_jeu_caractere' => 'Xuegu de carauteres del sitiu',
	'info_jours' => 'díes',
	'info_laisser_champs_vides' => 'dexar estos campos vacíos)',
	'info_langues' => 'Idiomes del sitiu',
	'info_ldap_ok' => 'L’autentificación LDAP ta instalada.',
	'info_lien_hypertexte' => 'Enllace d’hipertestu:',
	'info_liste_redacteurs_connectes' => 'Llista de los redactores conectáos', # MODIF
	'info_login_existant' => 'Esti nome ya esiste.',
	'info_login_trop_court' => 'El nome ye mui curtiu.',
	'info_logos' => 'Los logos',
	'info_maximum' => 'másimu:',
	'info_meme_rubrique' => 'Na mesma estaya',
	'info_message_en_redaction' => 'Los tos mensaxes en cursu de redacción',
	'info_message_technique' => 'Mensaxe téunicu:',
	'info_messagerie_interne' => 'Mensaxería interna',
	'info_mise_a_niveau_base' => 'axuste de la base de datos SQL',
	'info_mise_a_niveau_base_2' => '{{¡Atención!}} Instalasti una versión de los
  archivos de SPIP {anterior} a la que s’alcontraba
  enantes nesti sitiu: la base de datos puede tar
  perdida y el sitiu ya nun funcionará.<br />{{Reinstala los
  archivos de SPIP.}}',
	'info_modifier_auteur' => 'Modificar l’autor:',
	'info_modifier_rubrique' => 'Modificar la estaya:',
	'info_modifier_titre' => 'Modificar: @titre@',
	'info_mon_site_spip' => 'El mio sitiu SPIP',
	'info_moyenne' => 'media:',
	'info_multi_cet_article' => 'Llingua d’esti artículu:',
	'info_multi_langues_choisies' => 'Seleiciona de siguío les llingües disponibles pa los redactores del sitiu Web.
  Les llingües que ya tan usándose nel sitiu (amosaes en primer llugar) nun puen desactivase.', # MODIF
	'info_multi_secteurs' => '... ¿sólamente pa les estayes allugáes na raiz?',
	'info_nb_articles' => '@nb@ artículos',
	'info_nb_auteurs' => '@nb@ autores',
	'info_nb_messages' => '@nb@ mensaxes',
	'info_nb_mots_cles' => '@nb@ pallabres-clave',
	'info_nb_rubriques' => '@nb@ seiciones',
	'info_nb_visiteurs' => '@nb@ visitantes',
	'info_nom' => 'Nome',
	'info_nom_destinataire' => 'Nome del destinatariu',
	'info_nom_site' => 'Nome del to sitiu',
	'info_nombre_articles' => '@nb_articles@ artículos,',
	'info_nombre_rubriques' => '@nb_rubriques@ estayes,',
	'info_nombre_sites' => '@nb_sites@ sitios web,',
	'info_non_deplacer' => 'Nun desplazar...',
	'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP pue unviar, regularmente, l’anunciu de les caberes novedaes del sitiu
  (artículos y breves espublizaos apocayá).',
	'info_non_envoi_liste_nouveautes' => 'Nun mandar la llista de les novedáes',
	'info_non_modifiable' => 'nun pue camudase',
	'info_non_suppression_mot_cle' => 'nun quiero desaniciar esta pallabra-clave.',
	'info_notes' => 'Notes',
	'info_nouvel_article' => 'Artículu nuevu',
	'info_nouvelle_traduction' => 'Traducción nueva:',
	'info_numero_article' => 'ARTÍCULU NÚMBERU:',
	'info_obligatoire_02' => '[Obligatorio]', # MODIF
	'info_option_accepter_visiteurs' => 'Aceptar la inscripción de visitantes del sitiu públicu', # MODIF
	'info_option_ne_pas_accepter_visiteurs' => 'Refugar la inscripción de los visitantes', # MODIF
	'info_options_avancees' => 'OPCIONES AVANZÁES',
	'info_ou' => 'o...',
	'info_page_interdite' => 'Páxina torgada',
	'info_par_nom' => 'pol nome',
	'info_par_nombre_article' => 'pol númberu d’artículos',
	'info_par_statut' => 'pol cargu',
	'info_par_tri' => '’(por @tri@)’',
	'info_passe_trop_court' => 'La contraseña ye mui curtia.',
	'info_passes_identiques' => 'Les dos contraseñes nun concasen.',
	'info_plus_cinq_car' => 'más de 5 carauteres',
	'info_plus_cinq_car_2' => '(Más de 5 carauteres)',
	'info_plus_trois_car' => '(Más de 3 carauteres)',
	'info_popularite' => 'popularidá: @popularite@; visites: @visites@',
	'info_post_scriptum' => 'Post Scríptum',
	'info_post_scriptum_2' => 'Post Scríptum:',
	'info_pour' => 'pa',
	'info_preview_texte' => 'Ye posible previsualizar el sitiu como si tolos artículos y les breves (que tengan polo menos l’estatutu «propuestu») tuvieren espublizaos. ¿Esta posibilidá tien que tar abierta pa los alministradores namái, pa tolos redactores, o pa naide?', # MODIF
	'info_procedez_par_etape' => 'sigue pasu ente pasu',
	'info_procedure_maj_version' => 'hai que llanzar el procesu d’actualización a la fin d’adautar
 la base de datos a la nueva versión de SPIP.',
	'info_proxy_ok' => 'Preba del proxy superada.',
	'info_ps' => 'P.-S.',
	'info_publier' => 'espublizar',
	'info_publies' => 'Los tos artículos espublizáos en llinia',
	'info_question_accepter_visiteurs' => 'Si les cadarmes d’esti sitiu prevén el rexistru de visitantes ensin accesu a l’espaciu priváu, has d’activar la opción d’embaxo:', # MODIF
	'info_question_inscription_nouveaux_redacteurs' => '¿Aceutes les inscripciones de nuevos redactores dende’l
  sitiu públicu? Si aceutes, los visitantes podrán inscribise
  dende un formulariu automatizáu y tendrán accesu a l’espaciu priváu pa
  proponer artículos propios. <blockquote><i>Tres de la fase d’inscripción,
  los usuarios reciben un corréu electrónicu automáticu
  que-yos da los códigos d’accesu al sitiu priváu. Dellos
  agospiadores desactiven l’unvíu d’e-mails dende los sos
  sirvidores: nesti casu, la inscripción automática ye
  imposible.</i></blockquote>', # MODIF
	'info_racine_site' => 'Raiz del sitiu',
	'info_recharger_page' => 'Ties que recargar esta páxina nunos instantes.',
	'info_recherche_auteur_zero' => 'Nun hai resultaos pa «@cherche_auteur@».',
	'info_recommencer' => 'Vuelve a entamar',
	'info_redacteur_1' => 'Redactor',
	'info_redacteur_2' => 'con accesu a l’espaciu priváu (<i>encamentao</i>)',
	'info_redacteurs' => 'Redactores',
	'info_redaction_en_cours' => 'EN CURSU DE REDAICIÓN',
	'info_redirection' => 'Redireición',
	'info_refuses' => 'Los tos artículos refugáos',
	'info_reglage_ldap' => 'Opciones: <b>Axuste de la importación LDAP</b>',
	'info_renvoi_article' => '<b>Redireición.</b> Esti artículu reunvía a la páxina:',
	'info_reserve_admin' => 'Namái los alministradores puen camudar estes señes.', # MODIF
	'info_restreindre_rubrique' => 'Llendar la xestión a la estaya:',
	'info_resultat_recherche' => 'Resultaos de la gueta:',
	'info_rubriques' => 'Estayes',
	'info_rubriques_02' => 'estayes',
	'info_rubriques_trouvees' => 'Estayes alcontráes',
	'info_sans_titre' => 'Ensin títulu',
	'info_selection_chemin_acces' => '<b>Seleiciona</b> de siguío el camín d’accesu a la guía:',
	'info_signatures' => 'robles',
	'info_site' => 'Sitiu',
	'info_site_2' => 'sitiu:',
	'info_site_min' => 'sitiu Web',
	'info_site_reference_2' => 'Sitiu referenciau',
	'info_site_web' => 'SITIU WEB:', # MODIF
	'info_sites' => 'sitios',
	'info_sites_lies_mot' => 'Los sitios referenciaos enllazaos con esta pallabra-clave',
	'info_sites_proxy' => 'Utilizar un proxy',
	'info_sites_trouves' => 'Sitios alcontraos',
	'info_sous_titre' => 'Subtítulu:',
	'info_statut_administrateur' => 'Alministrador', # MODIF
	'info_statut_auteur' => 'Estatutu d’esti autor:',
	'info_statut_auteur_a_confirmer' => 'Inscripción por confirmar',
	'info_statut_auteur_autre' => 'Otru estatutu:',
	'info_statut_redacteur' => 'Redactor',
	'info_statut_utilisateurs_1' => 'Estatutu por omisión de los usuarios importaos', # MODIF
	'info_statut_utilisateurs_2' => 'Escueye l’estatutu que se-yos da a les persones presentes na guía LDAP cuando se conecten la primera vegada. Lluéu podrás camudar esti valor pa caún de los autores casu per casu.', # MODIF
	'info_suivi_activite' => 'Siguimientu de l’actividá editorial',
	'info_surtitre' => 'Antetítulu:',
	'info_syndication_integrale_1' => 'Esti sitiu ufre archivos de sindicación (ver «<a href="@url@">@titre@</a>»).',
	'info_syndication_integrale_2' => '¿Quies tresmitir los artículos ensembre, o nun esparder nás que un resume con dellos cientos de carauteres?',
	'info_table_prefix' => 'Pues cambear el prefixu del nome de les tables de datos (esto ye necesario dafechu si se quier instalar dellos sitios na mesma base de datos). Esti prefixu escríbese en lletres minúscules, ensin acentos, y ensin espacios.',
	'info_taille_maximale_images' => 'SPIP va comprebar el tamañu másimu de les imaxes que pue remanar (en millones de pixels).<br /> Les imaxes más grandes nun van reducise.',
	'info_taille_maximale_vignette' => 'Tamañu másimu de les viñetes xeneráes pol sistema:',
	'info_terminer_installation' => 'Agora pues finar el procesu d’instalación estándar.',
	'info_texte' => 'Testu',
	'info_texte_explicatif' => 'Testu explicativu',
	'info_texte_long' => '(el testu ye llargu: poro apaez en delles partes que volverán a amestase tres de la validación.)',
	'info_texte_message' => 'Testu del to mensaxe:', # MODIF
	'info_texte_message_02' => 'Testu del mensaxe',
	'info_titre' => 'Títulu:',
	'info_total' => 'total:',
	'info_tous_articles_en_redaction' => 'Tolos artículos en cursu de redaición',
	'info_tous_articles_presents' => 'Tolos artículos espublizaos nesta estaya',
	'info_tous_articles_refuses' => 'Tolos artículos refugaos',
	'info_tous_les' => 'tolos:',
	'info_tout_site' => 'Tou el sitiu',
	'info_tout_site2' => 'L’artículu nun ta traducíu a esta llingua.',
	'info_tout_site3' => 'L’artículu ta traducíu a esta llingua, pero después amestáronse modificaciones a l’artículu de referencia. La traducción tien que ponese al día.',
	'info_tout_site4' => 'L’artículu ta traducíu a esta llingua, y la traducción ta actualizada.',
	'info_tout_site5' => 'Artículu orixinal.',
	'info_tout_site6' => '<b>Atención :</b> sólo se amuesen los artículos orixinales.
Les traducciones asociense col orixinal,
con una color que indica el estáu:',
	'info_travail_colaboratif' => 'Trabayu en comuña nos artículos',
	'info_un_article' => 'un artículu,',
	'info_un_site' => 'un sitiu web,',
	'info_une_rubrique' => 'una estaya,',
	'info_une_rubrique_02' => '1 estaya',
	'info_url' => 'URL:',
	'info_url_proxy' => 'URL del proxy',
	'info_url_test_proxy' => 'URL de pruebes',
	'info_urlref' => 'Enllace d’hipertestu:',
	'info_utilisation_spip' => 'Agora puedes entamar a utilizar el sistema d’espublizamientu asistíu...',
	'info_visites_par_mois' => 'Amosar por meses:',
	'info_visiteur_1' => 'Visitante',
	'info_visiteur_2' => 'del sitiu públicu',
	'info_visiteurs' => 'Visitantes',
	'info_visiteurs_02' => 'Visitantes del sitiu públicu',
	'info_webmestre_forces' => 'Los webmasters anguaño tan conseñaos en <tt>@file_options@</tt>.', # MODIF
	'install_adresse_base_hebergeur' => 'Direición de la base datos asitiada pol agospiador web',
	'install_echec_annonce' => 'La instalación probablemente va fallar, o va producir un sitiu que nun funcione...',
	'install_extension_mbstring' => 'SPIP nun funciona con:',
	'install_extension_php_obligatoire' => 'SPIP esixe la estensión php:',
	'install_login_base_hebergeur' => 'Login de conexón conseñáu pol agospiador',
	'install_nom_base_hebergeur' => 'Nome de la base conseñáu pol agospiador:',
	'install_pas_table' => 'La base nun tien tables actualmente',
	'install_pass_base_hebergeur' => 'Contraseña de conexón conseñada pol agospiador',
	'install_php_version' => 'PHP versión @version@ nun ye suficiente (minimo= @minimum@)',
	'install_select_langue' => 'Escueye una llíngua y calca nel botón «siguiente» pa llanzar el procesu d’instalación.',
	'install_select_type_db' => 'Indicar el tipu de base de datos:',
	'install_select_type_mysql' => 'MySQL',
	'install_select_type_pg' => 'PostgreSQL',
	'install_select_type_sqlite2' => 'SQLite 2',
	'install_select_type_sqlite3' => 'SQLite 3',
	'install_serveur_hebergeur' => 'Sirvidor de base de datos conseñáu pol agospiador web',
	'install_table_prefix_hebergeur' => 'Prefixu de tabla conseñáu pol agospiamientu:',
	'install_tables_base' => 'Tables de la base',
	'install_types_db_connus' => 'SPIP sabe utilizar <b>MySQL</b> (la más estendida), <b>PostgreSQL</b> y <b>SQLite</b>.', # MODIF
	'install_types_db_connus_avertissement' => 'Atención: hai dellos plugins que nun funcionen más que con MySQL', # MODIF
	'intem_redacteur' => 'redactor',
	'intitule_licence' => 'Llicencia',
	'item_accepter_inscriptions' => 'Aceptar les inscripciones',
	'item_activer_messages_avertissement' => 'Activar los mensaxes d’avisu',
	'item_administrateur_2' => 'alministrador', # MODIF
	'item_afficher_calendrier' => 'Amosar na axenda',
	'item_autoriser_syndication_integrale' => 'Difundir los artículos completos en los archivos de sindicación',
	'item_choix_administrateurs' => 'los alministradores', # MODIF
	'item_choix_generation_miniature' => 'Xenerar automáticamente les imáxenes amenorgáes.',
	'item_choix_non_generation_miniature' => 'Nun xenerar imáxenes amenorgáes.',
	'item_choix_redacteurs' => 'los redactores',
	'item_choix_visiteurs' => 'los visitantes del sitiu públicu',
	'item_creer_fichiers_authent' => 'Crear los archivos .htpasswd',
	'item_login' => 'Login',
	'item_messagerie_agenda' => 'Activar la mensaxería y l’axenda',
	'item_mots_cles_association_articles' => 'a los artículos',
	'item_mots_cles_association_rubriques' => 'a les estayes',
	'item_mots_cles_association_sites' => 'a los sitios referenciaos o sindicaos.',
	'item_non' => 'Non',
	'item_non_accepter_inscriptions' => 'Nun aceutar les inscripciones',
	'item_non_activer_messages_avertissement' => 'Ensin mensaxes d’avisu',
	'item_non_afficher_calendrier' => 'Nun amosar nel calendariu',
	'item_non_autoriser_syndication_integrale' => 'Nun esparder más que un resume',
	'item_non_creer_fichiers_authent' => 'Nun crear estos archivos',
	'item_non_messagerie_agenda' => 'Desactivar la mensaxeria y l’axenda',
	'item_non_publier_articles' => 'Nun espublizar los artículos enantes de la fecha d’espublizamientu conseñada.',
	'item_nouvel_auteur' => 'Autor nuevu',
	'item_nouvelle_rubrique' => 'Estaya nueva',
	'item_oui' => 'Sí',
	'item_publier_articles' => 'Espublizar los artículos, cualquiera que sea la fecha d’espublizamientu.',
	'item_reponse_article' => 'Respuesta a l’artículu',
	'item_visiteur' => 'visitante',

	// J
	'jour_non_connu_nc' => 'n.c.',

	// L
	'label_bando_outils' => 'Barra de ferramientes',
	'label_bando_outils_afficher' => 'Amosar les ferramientes',
	'label_bando_outils_masquer' => 'Anubrir les ferramientes',
	'label_choix_langue' => 'Escueye la to llingua',
	'label_slogan_site' => 'Eslogan del sitiu',
	'label_taille_ecran' => 'Tamañu de la pantalla', # MODIF
	'label_texte_et_icones_navigation' => 'Menú de navegación',
	'label_texte_et_icones_page' => 'Presentación na páxina',
	'ldap_correspondance' => 'herencia del campu @champ@',
	'ldap_correspondance_1' => 'Herencia de campos LDAP',
	'ldap_correspondance_2' => 'Pa caún de los campos SPIP siguientes, conseñar el nome del campu LDAP correspondiente. Dexar balero pa nun llenalu, separtar con espacios o comes pa tentar dellos campos LDAP.',
	'lien_ajouter_auteur' => 'Amestar esti autor',
	'lien_email' => 'email',
	'lien_nom_site' => 'NOME DEL SITIU:',
	'lien_retirer_auteur' => 'Retirar l’autor',
	'lien_retirer_tous_auteurs' => 'Retirar tolos autores',
	'lien_site' => 'sitiu',
	'lien_tout_deplier' => 'Desplegalo too',
	'lien_tout_replier' => 'Replegalo too',
	'lien_tout_supprimer' => 'Desanicialo too',
	'lien_trier_nom' => 'Ordenar pol nome',
	'lien_trier_nombre_articles' => 'Ordenar pol númberu d’artículos',
	'lien_trier_statut' => 'Ordenar pol estau',
	'lien_voir_en_ligne' => 'VER EN LLINIA:',
	'logo_article' => 'LOGO DE L’ARTÍCULU', # MODIF
	'logo_auteur' => 'LOGO DE L’AUTOR O AUTORA', # MODIF
	'logo_rubrique' => 'LOGO DE LA ESTAYA', # MODIF
	'logo_site' => 'LOGO D’ESTI SITIU', # MODIF
	'logo_standard_rubrique' => 'LOGO ESTÁNDAR DE LES ESTAYES', # MODIF
	'logo_survol' => 'LOGO AL PASAR EL MUR', # MODIF

	// M
	'menu_aide_installation_choix_base' => 'Escoyeta de la base',
	'module_fichier_langue' => 'Ficheru de llíngua',
	'module_raccourci' => 'Atayu',
	'module_texte_affiche' => 'Testu amosau',
	'module_texte_explicatif' => 'Pues amestar los siguientes atayos nes cadarmes del sitiu públicu. Estos van traducise automáticamente a les diferentes llingües pa les qu’esista un archivu de llingua.',
	'module_texte_traduction' => 'L’archivu de llingua « @module@ » ta disponible en:',
	'mois_non_connu' => 'desconocíu',

	// N
	'nouvelle_version_spip' => 'Ta disponible la versión @version@ de SPIP', # MODIF

	// O
	'onglet_contenu' => 'Conteníu',
	'onglet_declarer_une_autre_base' => 'Declarar otra base',
	'onglet_discuter' => 'Discutiniu',
	'onglet_interactivite' => 'Interactividá',
	'onglet_proprietes' => 'Propiedáes',
	'onglet_repartition_actuelle' => 'actualmente',
	'onglet_sous_rubriques' => 'So-estayes',

	// P
	'page_pas_proxy' => 'Esta páxina nun debe pasar pol proxy',
	'pas_de_proxy_pour' => 'Si fai falta, indica les máquines o dominios pa los que esti proxy nun debe aplicase (por exemplu: @exemple@)',
	'plugin_charge_paquet' => 'Carga del paquete @name@',
	'plugin_charger' => 'Descargar',
	'plugin_erreur_charger' => 'fallu: nun ye posible cargar @zip@',
	'plugin_erreur_droit1' => 'El direutoriu <code>@dest@</code> nun ye accesible pa escritura.',
	'plugin_erreur_droit2' => 'Verifica los permisos d’esti direutoriu (o créalu si ye’l casu), o instala los archivos per FTP.',
	'plugin_erreur_zip' => 'falló pclzip col mensaxe: @status@',
	'plugin_etat_developpement' => 'en desarrollu',
	'plugin_etat_experimental' => 'esperimental',
	'plugin_etat_stable' => 'estable',
	'plugin_etat_test' => 'en prebes',
	'plugin_impossible_activer' => 'Nun ye posible activar el plugin @plugin@',
	'plugin_info_automatique1' => 'Si se quier autorizar la instalación automática de los plugins, hai que:',
	'plugin_info_automatique1_lib' => 'Si quies autorizar la instalación automática d’esta biblioteca, necesites:',
	'plugin_info_automatique2' => 'crear un direutoriu <code>@rep@</code> ;',
	'plugin_info_automatique3' => 'verificar que’l sirvidor tenga permisos pa escribir nesi direutoriu.',
	'plugin_info_automatique_creer' => 'que hai que crear na raiz del sitiu.',
	'plugin_info_automatique_exemples' => 'exemplos:',
	'plugin_info_automatique_ftp' => 'Puedes instalar plugins, per FTP, nel direutoriu <tt>@rep@</tt>',
	'plugin_info_automatique_lib' => 'Dellos plugins necesiten también permisu pa descargar archivos nel direutoriu <code>lib/</code>, a crear si ye’l casu na raiz del sitiu.',
	'plugin_info_automatique_liste' => 'Les tos llistes de plugins:',
	'plugin_info_automatique_liste_officielle' => 'los plugins oficiales',
	'plugin_info_automatique_liste_update' => 'Actualizar les llistes',
	'plugin_info_automatique_ou' => 'o...',
	'plugin_info_automatique_select' => 'Seleiciona un plugin d’embaxo: SPIP va descargalu y anicialu nel direutoriu <code>@rep@</code> ; si el plugin ya esiste, pondrase al día.',
	'plugin_info_plugins_dist_1' => 'Les estensiones darréu se carguen y s’activen nel direutoriu @plugins_dist@.', # MODIF
	'plugin_info_plugins_dist_2' => 'Estes nun pueden desactivase.', # MODIF
	'plugin_info_telecharger' => 'a descargar de @url@ y a instalar en @rep@',
	'plugin_librairies_installees' => 'Llibreríes instaláes',
	'plugin_necessite_lib' => 'Esti plugin necesita la llibrería @lib@',
	'plugin_necessite_plugin' => 'Necesita el plugin @plugin@ en versión @version@ mínimo.', # MODIF
	'plugin_necessite_spip' => 'Necesita SPIP en versión @version@ mínimo.',
	'plugin_source' => 'fonte: ',
	'plugin_titre_automatique' => 'Instalación automática',
	'plugin_titre_automatique_ajouter' => 'Amestar plugins',
	'plugin_titre_installation' => 'Instalación del complementu @plugin@',
	'plugin_zip_active' => 'Continúa pa activalu',
	'plugin_zip_adresse' => 'indica embaxo les señes d’un archivu zip de plugin a descargar, o mesmo les señes d’una llista de plugins.',
	'plugin_zip_adresse_champ' => 'Señes del plugin o de la llista ',
	'plugin_zip_content' => 'Contien los archivos siguientes (@taille@),<br />preparaos pa instalase nel direutoriu <code>@rep@</code>',
	'plugin_zip_installe_finie' => 'L’archivu @zip@ descomprimiose y quedó instalau.',
	'plugin_zip_installe_rep_finie' => 'L’archivu @zip@ descomprimiose y quedó instalau nel direutoriu @rep@',
	'plugin_zip_installer' => 'Pues instalalu agora.',
	'plugin_zip_telecharge' => 'Descargose l’archivu @zip@',
	'plugins_actif_aucun' => 'Dengún complementu activáu.',
	'plugins_actif_un' => 'Un complementu activáu.',
	'plugins_actifs' => '@count@ plugins activaos.',
	'plugins_actifs_liste' => 'Complementos activos', # MODIF
	'plugins_compte' => '@count@ plugins',
	'plugins_disponible_un' => 'Un complementu disponible.',
	'plugins_disponibles' => '@count@ plugins disponibles.',
	'plugins_erreur' => 'Error nos plugins: @plugins@',
	'plugins_liste' => 'Llista de los plugins',
	'plugins_liste_dist' => 'Estensiones', # MODIF
	'plugins_recents' => 'Complementos recientes.',
	'plugins_vue_hierarchie' => 'Xerarquía',
	'plugins_vue_liste' => 'Llista',
	'protocole_ldap' => 'Versión del protocolu:',

	// R
	'repertoire_plugins' => 'Direutoriu:',
	'required' => '[Obligatorio]', # MODIF

	// S
	'sans_heure' => 'ensin hora',
	'statut_admin_restreint' => '(almin llendau)', # MODIF

	// T
	'taille_cache_image' => 'Les imaxes calculáes automáticamente por SPIP (miniatures de documentos, títulos en formatu gráficu, funciones matemátiques en formatu TeX...) ocupen nel direutoriu @dir@ un total de @taille@.',
	'taille_cache_octets' => 'El tamañu de caché actualmente ye de @octets@.', # MODIF
	'taille_cache_vide' => 'La caché ta vacía.',
	'taille_repertoire_cache' => 'Tamañu del direutoriu de caché',
	'text_article_propose_publication' => 'Artículu propuestu pa espublizase.',
	'texte_acces_ldap_anonyme_1' => 'Dellos sirvidores LDAP nun acepten los accesos anónimos. Si esti ye’l casu hai que especificar una identificación d’accesu inicial a la fin de poder lluéu restolar la información na guía. Sicasí, nos más de los casos, los campos siguientes puen dexase vacíos.',
	'texte_admin_effacer_01' => 'Esta orde desanicia <i>tol</i> conteníu de la base de datos,
incluyíos <i>tolos</i> accesos de redactores y alministradores. Tres d’executalu, vas tener que llanzar la
reinstalación de SPIP pa crear una nueva base igual que un primer accesu d’alministrador.', # MODIF
	'texte_adresse_annuaire_1' => '(Si la guía ta instalada na mesma máquina que esti sitiu Web, ye probablemente «localhost».)',
	'texte_ajout_auteur' => 'El siguiente autor amestose a l’artículu:',
	'texte_annuaire_ldap_1' => 'Si ties accesu a una guía (LDAP), vas poder utilizala pa importar automáticamente usuarios a SPIP.', # MODIF
	'texte_article_statut' => 'Esti artículu ta:',
	'texte_article_virtuel' => 'Artículu virtual',
	'texte_article_virtuel_reference' => '<b>Artículu virtual:</b> artículu referenciau nel sitiu SPIP, magar que redirixe a otra URL. Pa desaniciar la redireición, esborra la URL d’enriba.',
	'texte_aucun_resultat_auteur' => 'Nun hai resultaos pa "@cherche_auteur@"',
	'texte_auteur_messagerie' => 'Esti sitiu pue amosate de mou permanente la llista de redactores coneutaos, lo que te permite intercambiar mensaxes en direutu. Pues decidir nun apaecer nesa llista (ser «invisible» pa los demás usuarios).', # MODIF
	'texte_auteurs' => 'LOS AUTORES',
	'texte_choix_base_1' => 'Escueye la base de datos:',
	'texte_choix_base_2' => 'El sirvidor SQL contién delles bases de datos.',
	'texte_choix_base_3' => '<b>Seleiciona</b> de siguío la que te conseñaren nel agospiamientu:',
	'texte_choix_table_prefix' => 'Prefixu de les tables:',
	'texte_compte_element' => '@count@ elementu',
	'texte_compte_elements' => '@count@ elementos',
	'texte_conflit_edition_correction' => 'Compreba embaxo les diferencies ente les dos versiones del testu; también pues copiar los tos cambéos y, de siguío, volver a entamar',
	'texte_connexion_mysql' => 'Consulta la información que te dieren nel to agospiamientu web: ties que atopar el sirvidor de base datos que te ufre y los códigos de identificación pa conectate.',
	'texte_contenu_article' => '(Conteníu de l’artículu en delles pallabres.)',
	'texte_contenu_articles' => 'Según la maquetación que uses pal to sitiu, seique decidas
  que dellos elementos de los artículos nun van utilizase.
  Usa la llista d’embaxo pa indicar los elementos que van tar disponibles.',
	'texte_crash_base' => 'Si la to base de datos ta
   caída, pues tentar una reparación
   automática.',
	'texte_creer_rubrique' => 'Enantes que puedas escribir artículos,<br /> tienes que crear una estaya.',
	'texte_date_creation_article' => 'FECHA DE CREACIÓN DE L’ARTÍCULU:',
	'texte_date_publication_anterieure' => 'Fecha de redaición anterior:',
	'texte_date_publication_anterieure_nonaffichee' => 'Nun amosar fecha de redaición anterior.',
	'texte_date_publication_article' => 'FECHA D’ESPUBLIZAMIENTU EN LLINIA:',
	'texte_descriptif_rapide' => 'Descripción rápida',
	'texte_effacer_base' => 'Desaniciar la base de datos SPIP',
	'texte_effacer_statistiques' => 'Desaniciar les estadístiques',
	'texte_en_cours_validation' => 'Los artículos y breves d’embaxo tan propuestos pa espublizase.', # MODIF
	'texte_enrichir_mise_a_jour' => 'Pues arriquecer la paxinación del testu utilizando los «atayos tipográficos».',
	'texte_fichier_authent' => '<b>¿Tien SPIP que crear los ficheros especiales <tt>.htpasswd</tt>
  y <tt>.htpasswd-admin</tt> na carpeta @dossier@?</b><p>
  Estos ficheros pueden sirvite pa torgar l’accesu, tanto de los autores
  como de los alministradores a otres partes del to sitiu web
  (al programa esternu d’estadístiques, por exemplu).</p><p>
  Si nun vas utilizalo, puedes dexar esta opción
 col so valor predetermináu (nun crear
 esos ficheros).</p>', # MODIF
	'texte_informations_personnelles_1' => 'Agora el sistema va create un accesu personalizáu al sitiu.',
	'texte_informations_personnelles_2' => '(Nota: si esto ye una reinstalación, y el to accesu siempre funciona, pues', # MODIF
	'texte_introductif_article' => '(Testu d’introducción de l’artículu.)',
	'texte_jeu_caractere' => 'Encamiéntase emplegar, pal to sitiu, l’alfabetu universal (<tt>utf-8</tt>): esti permite amosar los testos en toes les llingües, y ya nun da problemes de compatibilidá colos ñavegadores modernos.',
	'texte_jeu_caractere_3' => 'Esti sitiu ta instaláu actualmente col xuegu de carauteres:',
	'texte_jeu_caractere_4' => 'Si esto nun concasa cola realidá de los datos (siguir, por exemplu, tres d’una restauración de la base de datos), o si <em>tas arrancando esti sitiu</em> y quies entamar con otru xuegu de carauteres, conseña esti darréu:',
	'texte_login_ldap_1' => '(Dexar vacío pa un accesu anónimu, o conseñar el camín ensembre, por exemplu «<tt>uid=dupont, ou=users, dc=mio-dominiu, dc=com</tt> ».)',
	'texte_login_precaution' => '¡Atención! Esti ye l’usuariu col que tas coneutau actualmente.
 Utiliza esti formulariu con procuru...',
	'texte_messagerie_agenda' => 'Una mensaxería permite-yos a los redactores del sitiu comunicase direutamente ente ellos nel espaciu privau del sitiu. La mensaxería va asociada con una axenda.', # MODIF
	'texte_mise_a_niveau_base_1' => 'Tas acabante de poner al día los archivos de SPIP.
 Agora fai falta actualizar la base de datos
 del sitiu.',
	'texte_modifier_article' => 'Iguar l’artículu:',
	'texte_multilinguisme' => 'Si quiés xuestionar artículos en delles llingües, con una ñavegación complexa, pues amestar un menú de seleición de llingua nos articulos y/o nes estayes, al aldu de la organización del sitiu.', # MODIF
	'texte_multilinguisme_trad' => 'Igualmente pues activar un sistema de xestión de enllaces ente les distintes traducciones d’un artículu.', # MODIF
	'texte_non_compresse' => '<i>non comprimíu</i> (el to sirvidor nun soporta esta carauterística)',
	'texte_nouvelle_version_spip_1' => 'Vienes d’instalar una versión nueva de SPIP.',
	'texte_nouvelle_version_spip_2' => 'Esta nueva versión necesita una actualización más completa que la de vezu. Si yes el webmaster del sitiu, tienes de desaniciar el ficheru @connect@ y siguir cola instalación p’anovar los parámetros de conexón cola base de datos.<p> (NB.: si escaecisti los tos parámetros de conexón, echa-y una güeyada al ficheru @connect@ enantes de desanicialu...)</p>',
	'texte_operation_echec' => 'Torna a la páxina precedente, seleiciona otra base o crea una nueva. Compreba la información ufrida pol to agospiamientu web.',
	'texte_plus_trois_car' => 'más de 3 carauteres',
	'texte_plusieurs_articles' => 'Alcontráronse dellos autores pa "@cherche_auteur@":',
	'texte_port_annuaire' => '(El valor indicáu por omisión convién polo xeneral.)',
	'texte_presente_plugin' => 'Esta páxina llista los plugins disponibles nel sitiu. Pues activar los plugins necesarios marcando el cuadru correspondiente.',
	'texte_proposer_publication' => 'Cuando tea termináu l’artículu,<br /> pues proponelu pa espublizar.',
	'texte_proxy' => 'En ciertos casos (intranet, redes protexíes), los sitios esternos (documentación de SPIP, sitios sindicaos, etc.) nun son accesibles más que al traviés d’un <i>proxy HTTP</i>. Si ye’l casu, conseña embaxo les señes, na forma @proxy_en_cours@. En xeneral, esti cuadru déxase vacíu.',
	'texte_publication_articles_post_dates' => '¿Cómo tien que comportase SPIP colos artículos nos que la
  fecha d’espublizamientu ta conseñada pa otru
  momentu futuru?',
	'texte_rappel_selection_champs' => '[Nun escaezas seleicionar correutamente esti campu.]',
	'texte_recalcul_page' => 'Si quies
recalcular una sola páxina, pasa meyor pel espaciu públicu y calca nel botón «recalcular».',
	'texte_recuperer_base' => 'Iguar la base de datos',
	'texte_reference_mais_redirige' => 'artículu referenciáu nel to sitiu SPIP, pero redirixíu a otra URL.',
	'texte_requetes_echouent' => '<b>Cuando ciertes consultes SQL fallen
  sistemáticamente y ensin razón aparente, ye
  posible que seya por cuenta de la mesma base
  de datos.</b><p>
  El sirvidor SQL tien la posibilidá d’iguar les sos
  tables cuando estes tan dañaes por
  accidente. Equí pues tentar esta reparación; en
  casu de fallu, guarda una copia del mensaxe, que tendrá,
  seique, índices de lo que nun funciona...</p><p>
  Si el problema siguiere, ponte en contautu col to
  agospiador.</p>',
	'texte_selection_langue_principale' => 'Más embaxo pues seleicionar la «llingua principal» del sitiu. Esti axuste nun te obliga - ¡por suerte! - a escribir los artículos na llingua seleicionada, sinon que permite afitar:
 <ul><li> el formatu por omisión de les feches pal sitiu públicu;</li>
 <li> la natura del motor tipográficu que SPIP tien que utilizar pa representar los testos;</li>
 <li> la llingua utilizada nos formularios del sitiu públicu;</li>
 <li> la llingua por omisión pa presentar l’espaciu priváu.</li></ul>',
	'texte_sous_titre' => 'Subtítulu',
	'texte_statistiques_visites' => '(barres prietes:  domingu / curva prieta: evolución de la media)',
	'texte_statut_attente_validation' => 'esperando validación',
	'texte_statut_publies' => 'espublizaos en llinia',
	'texte_statut_refuses' => 'refugáos',
	'texte_suppression_fichiers' => 'Utilza esta orde pa desaniciar tolos archivos presentes
na caché de SPIP. Esto permite por exemplu forzar un recálculu de toes les páxines si
vienes de facer cambéos importantes nel grafismu o na estructura del sitiu.',
	'texte_sur_titre' => 'Antetítulu',
	'texte_table_ok' => ': esta tabla ta bién.',
	'texte_tentative_recuperation' => 'Intentu d’igua',
	'texte_tenter_reparation' => 'Tentar una reparación de la base de datos',
	'texte_test_proxy' => 'Pa facer una preba d’esti proxy, conseña equí les señes d’un sitiu Web
    que quieras prebar.',
	'texte_titre_02' => 'Títulu:',
	'texte_titre_obligatoire' => '<b>Títulu</b> [Obligatorio]',
	'texte_travail_article' => '@nom_auteur_modif@ trabayó nesti artículu hai @date_diff@ minutos',
	'texte_travail_collaboratif' => 'Si ye frecuente que dellos redactores
  trabayen nel mesmu artículu, el sistema
  pue amosar los artículos «abiertos» recientemente
  a la fin d’evitar modificaciones simultánees.
  Esta opción ta desactivada por omisión
  pa evitar l’apaición de mensaxes d’avisu
  intempestivos.', # MODIF
	'texte_vide' => 'vacíu',
	'texte_vider_cache' => 'Vaciar la caché',
	'titre_admin_tech' => 'Mantenimientu técnicu',
	'titre_ajouter_un_auteur' => 'Amestar un autor',
	'titre_ajouter_un_mot' => 'Amestar una pallabra-clave',
	'titre_cadre_afficher_article' => 'Amosar los artículos',
	'titre_cadre_afficher_traductions' => 'Amosar l’estau de les traducciones pa les llingües siguientes:',
	'titre_cadre_ajouter_auteur' => 'AMESTAR UN AUTOR:',
	'titre_cadre_interieur_rubrique' => 'Dientro de la estaya',
	'titre_cadre_numero_auteur' => 'AUTOR NÚMBERU',
	'titre_cadre_signature_obligatoire' => '<b>Robla</b> [Obligatoria]<br />',
	'titre_config_contenu_notifications' => 'Notificaciones',
	'titre_config_contenu_prive' => 'Nel espaciu priváu',
	'titre_config_contenu_public' => 'Nel sitiu públicu',
	'titre_config_fonctions' => 'Configuración del sitiu',
	'titre_config_langage' => 'Configurar la llingua',
	'titre_configuration' => 'Configuración del sitiu',
	'titre_configurer_preferences' => 'Configurar les tos preferencies',
	'titre_conflit_edition' => 'Conflictu durante la edición',
	'titre_connexion_ldap' => 'Axustes: <b>La to conexón LDAP</b>',
	'titre_groupe_mots' => 'GRUPU DE PALLABRES:',
	'titre_identite_site' => 'Identidá del sitiu',
	'titre_langue_article' => 'LLINGUA DE L’ARTICULU', # MODIF
	'titre_langue_rubrique' => 'LLINGUA DE LA ESTAYA', # MODIF
	'titre_langue_trad_article' => 'LLINGUA Y TRADUCCIONES DE L’ARTÍCULU',
	'titre_les_articles' => 'LOS ARTÍCULOS',
	'titre_messagerie_agenda' => 'Mensaxería y axenda',
	'titre_naviguer_dans_le_site' => 'Ñavegar pol sitiu Web...',
	'titre_nouvelle_rubrique' => 'Estaya nueva',
	'titre_numero_rubrique' => 'ESTAYA NÚMBERU:',
	'titre_page_articles_edit' => 'Camudar: @titre@',
	'titre_page_articles_page' => 'Los artículos',
	'titre_page_articles_tous' => 'Tou el sitiu',
	'titre_page_calendrier' => 'Axenda de @nom_mois@ @annee@',
	'titre_page_config_contenu' => 'Configuración del sitiu',
	'titre_page_delete_all' => 'desaniciu total e irreversible',
	'titre_page_recherche' => 'Resultaos de la gueta @recherche@',
	'titre_page_statistiques_referers' => 'Estadístiques (enllaces entrantes)',
	'titre_page_upgrade' => 'Actualización de SPIP',
	'titre_publication_articles_post_dates' => 'Publicación d’artículos con fecha posterior',
	'titre_reparation' => 'Igua',
	'titre_suivi_petition' => 'Siguimientu de les solicitudes',
	'tls_ldap' => 'Transport Layer Security (TLS):',
	'trad_article_traduction' => 'Toles versiones d’esti artículu:',
	'trad_delier' => 'Ya nun enllazar esti artículu coles sos traduciones ', # MODIF
	'trad_lier' => 'Esti artículu ye una tradución del artículu númberu:',
	'trad_new' => 'Escribir una nueva torna d’esti artículu', # MODIF

	// U
	'utf8_convert_erreur_orig' => 'Error: el xuegu de carautéres @charset@ nun ta soportáu.',

	// V
	'version' => 'Versión:',
];
